MCREEP :: fitting of creep data to various pre-defined models
-------------------------------------------------------------
* *MCREEP* is a Python package that...
	- Reads creep data from tensile or indentation experiments
	- Fits the experimental data to various pre-defined models

Documentation, help and examples
--------------------------------

More detailed help, demo and source code including documentation are in
[GitHub](https://mirekslouf.github.io/mcreep).

Versions of MCREEP
------------------
* Version 1.0 = finalized, working for both indentation and tensile creep
